@@ -12,11 +12,13 @@
 #pragma implementation
 #endif
 
+#include <aconf.h>
 #include <stdlib.h>
 #include <stddef.h>
 #include <string.h>
 #include <ctype.h>
-#include <GString.h>
+#include "gtypes.h"
+#include "GString.h"
 
 static inline int size(int len) {
   int delta;
@@ -44,18 +46,25 @@ GString::GString() {
   s[0] = '\0';
 }
 
-GString::GString(char *s1) {
-  int n = strlen(s1);
+GString::GString(const char *sA) {
+  int n = strlen(sA);
 
   s = NULL;
   resize(length = n);
-  memcpy(s, s1, n + 1);
+  memcpy(s, sA, n + 1);
 }
 
-GString::GString(char *s1, int length1) {
+GString::GString(const char *sA, int lengthA) {
   s = NULL;
-  resize(length = length1);
-  memcpy(s, s1, length * sizeof(char));
+  resize(length = lengthA);
+  memcpy(s, sA, length * sizeof(char));
+  s[length] = '\0';
+}
+
+GString::GString(GString *str, int idx, int lengthA) {
+  s = NULL;
+  resize(length = lengthA);
+  memcpy(s, str->getCString() + idx, length);
   s[length] = '\0';
 }
 
@@ -75,6 +84,32 @@ GString::GString(GString *str1, GString *str2) {
   memcpy(s + n1, str2->getCString(), n2 + 1);
 }
 
+GString *GString::fromInt(int x) {
+  char buf[24]; // enough space for 64-bit ints plus a little extra
+  GBool neg;
+  Guint y;
+  int i;
+
+  i = 24;
+  if (x == 0) {
+    buf[--i] = '0';
+  } else {
+    if ((neg = x < 0)) {
+      y = (Guint)-x;
+    } else {
+      y = (Guint)x;
+    }
+    while (i > 0 && y > 0) {
+      buf[--i] = '0' + y % 10;
+      y /= 10;
+    }
+    if (neg && i > 0) {
+      buf[--i] = '-';
+    }
+  }
+  return new GString(buf + i, 24 - i);
+}
+
 GString::~GString() {
   delete[] s;
 }
@@ -101,7 +136,7 @@ GString *GString::append(GString *str) {
   return this;
 }
 
-GString *GString::append(char *str) {
+GString *GString::append(const char *str) {
   int n = strlen(str);
 
   resize(length + n);
@@ -110,10 +145,10 @@ GString *GString::append(char *str) {
   return this;
 }
 
-GString *GString::append(char *str, int length1) {
-  resize(length + length1);
-  memcpy(s + length, str, length1);
-  length += length1;
+GString *GString::append(const char *str, int lengthA) {
+  resize(length + lengthA);
+  memcpy(s + length, str, lengthA);
+  length += lengthA;
   s[length] = '\0';
   return this;
 }
@@ -141,7 +176,7 @@ GString *GString::insert(int i, GString *str) {
   return this;
 }
 
-GString *GString::insert(int i, char *str) {
+GString *GString::insert(int i, const char *str) {
   int n = strlen(str);
   int j;
 
@@ -153,14 +188,14 @@ GString *GString::insert(int i, char *str) {
   return this;
 }
 
-GString *GString::insert(int i, char *str, int length1) {
+GString *GString::insert(int i, const char *str, int lengthA) {
   int j;
 
-  resize(length + length1);
+  resize(length + lengthA);
   for (j = length; j >= i; --j)
-    s[j+length1] = s[j];
-  memcpy(s+i, str, length1);
-  length += length1;
+    s[j+lengthA] = s[j];
+  memcpy(s+i, str, lengthA);
+  length += lengthA;
   return this;
 }
 
