@@ -15,7 +15,7 @@
 
 #include <stddef.h>
 #include <X11/Xlib.h>
-#include <LTKWidget.h>
+#include "LTKWidget.h"
 
 //------------------------------------------------------------------------
 // LTKDblBufCanvas
@@ -24,15 +24,13 @@
 class LTKDblBufCanvas: public LTKWidget {
 public:
 
-  //---------- constructors and destructor ----------
+  //---------- constructor and destructor ----------
 
-  LTKDblBufCanvas(char *name1, int widgetNum1,
-		  int minWidth1, int minHeight1);
+  LTKDblBufCanvas(char *nameA, int widgetNumA,
+		  int minWidthA, int minHeightA);
 
   virtual ~LTKDblBufCanvas();
 
-  virtual LTKWidget *copy() { return new LTKDblBufCanvas(this); }
-
   //---------- special access ----------
 
   Pixmap getPixmap() { return pixmap; }
@@ -48,8 +46,6 @@ public:
 
 protected:
 
-  LTKDblBufCanvas(LTKDblBufCanvas *canvas);
-
   int minWidth, minHeight;	// minimum size
   Pixmap pixmap;		// the off-screen drawable
 };
