@@ -10,13 +10,14 @@
 #pragma implementation
 #endif
 
+#include <aconf.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <stddef.h>
 #include <stdarg.h>
-#include <LTKMisc.h>
-#include <LTKWindow.h>
-#include <LTKWidget.h>
+#include "LTKMisc.h"
+#include "LTKWindow.h"
+#include "LTKWidget.h"
 
 void ltkError(char *msg, ...) {
   va_list args;
