@@ -26,21 +26,21 @@ public:
 
   //---------- constructor and destructor ----------
 
-  LTKScrollingCanvas(char *name1, int widgetNum1,
-		     int realWidth1, int realHeight1,
-		     int minWidth1, int minHeight1);
+  LTKScrollingCanvas(char *nameA, int widgetNumA,
+		     int realWidthA, int realHeightA,
+		     int minWidthA, int minHeightA);
 
   virtual ~LTKScrollingCanvas();
 
   //---------- special access ----------
 
   Pixmap getPixmap() { return pixmap; }
-  void resize(int realWidth1, int realHeight1);
+  void resize(int realWidthA, int realHeightA);
   int getRealWidth() { return realWidth; }
   int getRealHeight() { return realHeight; }
   int getMaxX() { return realWidth >= width ? realWidth - width : 0; }
   int getMaxY() { return realHeight >= height ? realHeight - height : 0; }
-  void scroll(int x, int y);
+  void scroll(int xA, int yA);
   void redrawRect(int x1, int y1, int x2, int y2);
 
   //---------- layout ----------
