@@ -10,41 +10,28 @@
 #pragma implementation
 #endif
 
+#include <aconf.h>
 #include <stdio.h>
 #include <stddef.h>
 #include <stdarg.h>
-#include "gtypes.h"
-#include "Params.h"
+#include "GlobalParams.h"
 #include "Error.h"
 
-FILE *errFile;
-GBool errQuiet;
-
-void errorInit() {
-  if (errQuiet) {
-    errFile = NULL;
-  } else {
-    errFile = stderr;
-  }
-}
-
 void CDECL error(int pos, char *msg, ...) {
   va_list args;
 
-  if (errQuiet) {
+  // NB: this can be called before the globalParams object is created
+  if (globalParams && globalParams->getErrQuiet()) {
     return;
   }
-  if (printCommands) {
-    fflush(stdout);
-  }
   if (pos >= 0) {
-    fprintf(errFile, "Error (%d): ", pos);
+    fprintf(stderr, "Error (%d): ", pos);
   } else {
-    fprintf(errFile, "Error: ");
+    fprintf(stderr, "Error: ");
   }
   va_start(args, msg);
-  vfprintf(errFile, msg, args);
+  vfprintf(stderr, msg, args);
   va_end(args);
-  fprintf(errFile, "\n");
-  fflush(errFile);
+  fprintf(stderr, "\n");
+  fflush(stderr);
 }
