@@ -10,6 +10,7 @@
 #pragma implementation
 #endif
 
+#include <aconf.h>
 #include <stdlib.h>
 #include <stddef.h>
 #include <string.h>
@@ -17,25 +18,100 @@
 #include "Lexer.h"
 #include "Error.h"
 
+//------------------------------------------------------------------------
+
+// A '1' in this array means the character is white space.  A '1' or
+// '2' means the character ends a name or command.
+static char specialChars[256] = {
+  1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1, 1, 0, 0,   // 0x
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   // 1x
+  1, 0, 0, 0, 0, 2, 0, 0, 2, 2, 0, 0, 0, 0, 0, 2,   // 2x
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0,   // 3x
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   // 4x
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0,   // 5x
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   // 6x
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0,   // 7x
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   // 8x
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   // 9x
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   // ax
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   // bx
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   // cx
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   // dx
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,   // ex
+  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0    // fx
+};
+
 //------------------------------------------------------------------------
 // Lexer
 //------------------------------------------------------------------------
 
-Lexer::Lexer(Stream *str1, GBool freeStream1) {
-  str = str1;
-  str->reset();
-  freeStream = freeStream1;
+Lexer::Lexer(XRef *xref, Stream *str) {
+  Object obj;
+
+  curStr.initStream(str);
+  streams = new Array(xref);
+  streams->add(curStr.copy(&obj));
+  strPtr = 0;
+  freeArray = gTrue;
+  curStr.streamReset();
+}
+
+Lexer::Lexer(XRef *xref, Object *obj) {
+  Object obj2;
+
+  if (obj->isStream()) {
+    streams = new Array(xref);
+    freeArray = gTrue;
+    streams->add(obj->copy(&obj2));
+  } else {
+    streams = obj->getArray();
+    freeArray = gFalse;
+  }
+  strPtr = 0;
+  if (streams->getLength() > 0) {
+    streams->get(strPtr, &curStr);
+    curStr.streamReset();
+  }
 }
 
 Lexer::~Lexer() {
-  if (freeStream)
-    delete str;
+  if (!curStr.isNone()) {
+    curStr.streamClose();
+    curStr.free();
+  }
+  if (freeArray) {
+    delete streams;
+  }
+}
+
+int Lexer::getChar() {
+  int c;
+
+  c = EOF;
+  while (!curStr.isNone() && (c = curStr.streamGetChar()) == EOF) {
+    curStr.streamClose();
+    curStr.free();
+    ++strPtr;
+    if (strPtr < streams->getLength()) {
+      streams->get(strPtr, &curStr);
+      curStr.streamReset();
+    }
+  }
+  return c;
+}
+
+int Lexer::lookChar() {
+  if (curStr.isNone()) {
+    return EOF;
+  }
+  return curStr.streamLookChar();
 }
 
 Object *Lexer::getObj(Object *obj) {
   char *p;
   int c, c2;
   GBool comment, neg, done;
+  int numParen;
   int xi;
   double xf, scale;
   GString *s;
@@ -44,14 +120,15 @@ Object *Lexer::getObj(Object *obj) {
   // skip whitespace and comments
   comment = gFalse;
   while (1) {
-    if ((c = str->getChar()) == EOF)
+    if ((c = getChar()) == EOF) {
       return obj->initEOF();
+    }
     if (comment) {
       if (c == '\r' || c == '\n')
 	comment = gFalse;
     } else if (c == '%') {
       comment = gTrue;
-    } else if (!isspace(c)) {
+    } else if (specialChars[c] != 1) {
       break;
     }
   }
@@ -73,12 +150,12 @@ Object *Lexer::getObj(Object *obj) {
       xi = c - '0';
     }
     while (1) {
-      c = str->lookChar();
+      c = lookChar();
       if (isdigit(c)) {
-	str->getChar();
+	getChar();
 	xi = xi * 10 + (c - '0');
       } else if (c == '.') {
-	str->getChar();
+	getChar();
 	goto doReal;
       } else {
 	break;
@@ -92,10 +169,11 @@ Object *Lexer::getObj(Object *obj) {
     xf = xi;
     scale = 0.1;
     while (1) {
-      c = str->lookChar();
-      if (!isdigit(c))
+      c = lookChar();
+      if (!isdigit(c)) {
 	break;
-      str->getChar();
+      }
+      getChar();
       xf = xf + scale * (c - '0');
       scale *= 0.1;
     }
@@ -108,25 +186,38 @@ Object *Lexer::getObj(Object *obj) {
   case '(':
     p = tokBuf;
     n = 0;
+    numParen = 1;
     done = gFalse;
     s = NULL;
     do {
       c2 = EOF;
-      switch (c = str->getChar()) {
+      switch (c = getChar()) {
 
       case EOF:
+#if 0
+      // This breaks some PDF files, e.g., ones from Photoshop.
       case '\r':
       case '\n':
+#endif
 	error(getPos(), "Unterminated string");
 	done = gTrue;
 	break;
 
+      case '(':
+	++numParen;
+	c2 = c;
+	break;
+
       case ')':
-	done = gTrue;
+	if (--numParen == 0) {
+	  done = gTrue;
+	} else {
+	  c2 = c;
+	}
 	break;
 
       case '\\':
-	switch (c = str->getChar()) {
+	switch (c = getChar()) {
 	case 'n':
 	  c2 = '\n';
 	  break;
@@ -150,21 +241,22 @@ Object *Lexer::getObj(Object *obj) {
 	case '0': case '1': case '2': case '3':
 	case '4': case '5': case '6': case '7':
 	  c2 = c - '0';
-	  c = str->lookChar();
+	  c = lookChar();
 	  if (c >= '0' && c <= '7') {
-	    str->getChar();
+	    getChar();
 	    c2 = (c2 << 3) + (c - '0');
-	    c = str->lookChar();
+	    c = lookChar();
 	    if (c >= '0' && c <= '7') {
-	      str->getChar();
+	      getChar();
 	      c2 = (c2 << 3) + (c - '0');
 	    }
 	  }
 	  break;
 	case '\r':
-	  c = str->lookChar();
-	  if (c == '\n')
-	    str->getChar();
+	  c = lookChar();
+	  if (c == '\n') {
+	    getChar();
+	  }
 	  break;
 	case '\n':
 	  break;
@@ -207,11 +299,33 @@ Object *Lexer::getObj(Object *obj) {
   case '/':
     p = tokBuf;
     n = 0;
-    while ((c = str->lookChar()) != EOF && !isspace(c) &&
-	   c != '/' && c != '%' && c != '(' && c != ')' &&
-	   c != '<' && c != '>' && c != '[' && c != ']' &&
-	   c != '{' && c != '}') {
-      str->getChar();
+    while ((c = lookChar()) != EOF && !specialChars[c]) {
+      getChar();
+      if (c == '#') {
+	c2 = lookChar();
+	if (c2 >= '0' && c2 <= '9') {
+	  c = c2 - '0';
+	} else if (c2 >= 'A' && c2 <= 'F') {
+	  c = c2 - 'A' + 10;
+	} else if (c2 >= 'a' && c2 <= 'f') {
+	  c = c2 - 'a' + 10;
+	} else {
+	  goto notEscChar;
+	}
+	getChar();
+	c <<= 4;
+	c2 = getChar();
+	if (c2 >= '0' && c2 <= '9') {
+	  c += c2 - '0';
+	} else if (c2 >= 'A' && c2 <= 'F') {
+	  c += c2 - 'A' + 10;
+	} else if (c2 >= 'a' && c2 <= 'f') {
+	  c += c2 - 'a' + 10;
+	} else {
+	  error(getPos(), "Illegal digit in hex char in name");
+	}
+      }
+     notEscChar:
       if (++n == tokBufSize) {
 	error(getPos(), "Name token too long");
 	break;
@@ -232,11 +346,11 @@ Object *Lexer::getObj(Object *obj) {
 
   // hex string or dict punctuation
   case '<':
-    c = str->lookChar();
+    c = lookChar();
 
     // dict punctuation
     if (c == '<') {
-      str->getChar();
+      getChar();
       tokBuf[0] = tokBuf[1] = '<';
       tokBuf[2] = '\0';
       obj->initCmd(tokBuf);
@@ -248,20 +362,20 @@ Object *Lexer::getObj(Object *obj) {
       c2 = 0;
       s = NULL;
       while (1) {
-	c = str->getChar();
+	c = getChar();
 	if (c == '>') {
 	  break;
 	} else if (c == EOF) {
 	  error(getPos(), "Unterminated hex string");
 	  break;
-	} else if (!isspace(c)) {
+	} else if (specialChars[c] != 1) {
 	  c2 = c2 << 4;
 	  if (c >= '0' && c <= '9')
-	    c2 += (c - '0');
+	    c2 += c - '0';
 	  else if (c >= 'A' && c <= 'F')
-	    c2 += (c - 'A' + 10);
+	    c2 += c - 'A' + 10;
 	  else if (c >= 'a' && c <= 'f')
-	    c2 += (c - 'a' + 10);
+	    c2 += c - 'a' + 10;
 	  else
 	    error(getPos(), "Illegal character <%02x> in hex string", c);
 	  if (++m == 2) {
@@ -292,9 +406,9 @@ Object *Lexer::getObj(Object *obj) {
 
   // dict punctuation
   case '>':
-    c = str->lookChar();
+    c = lookChar();
     if (c == '>') {
-      str->getChar();
+      getChar();
       tokBuf[0] = tokBuf[1] = '>';
       tokBuf[2] = '\0';
       obj->initCmd(tokBuf);
@@ -317,11 +431,8 @@ Object *Lexer::getObj(Object *obj) {
     p = tokBuf;
     *p++ = c;
     n = 1;
-    while ((c = str->lookChar()) != EOF && !isspace(c) &&
-	   c != '%' && c != '(' && c != ')' &&
-	   c != '<' && c != '>' && c != '[' && c != ']' &&
-	   c != '{' && c != '}') {
-      str->getChar();
+    while ((c = lookChar()) != EOF && !specialChars[c]) {
+      getChar();
       if (++n == tokBufSize) {
 	error(getPos(), "Command token too long");
 	break;
@@ -329,14 +440,15 @@ Object *Lexer::getObj(Object *obj) {
       *p++ = c;
     }
     *p = '\0';
-    if (!strcmp(tokBuf, "true"))
+    if (tokBuf[0] == 't' && !strcmp(tokBuf, "true")) {
       obj->initBool(gTrue);
-    else if (!strcmp(tokBuf, "false"))
+    } else if (tokBuf[0] == 'f' && !strcmp(tokBuf, "false")) {
       obj->initBool(gFalse);
-    else if (!strcmp(tokBuf, "null"))
+    } else if (tokBuf[0] == 'n' && !strcmp(tokBuf, "null")) {
       obj->initNull();
-    else
+    } else {
       obj->initCmd(tokBuf);
+    }
     break;
   }
 
@@ -347,12 +459,14 @@ void Lexer::skipToNextLine() {
   int c;
 
   while (1) {
-    c = str->getChar();
-    if (c == EOF || c == '\n')
+    c = getChar();
+    if (c == EOF || c == '\n') {
       return;
+    }
     if (c == '\r') {
-      if ((c = str->lookChar()) == '\n')
-	str->getChar();
+      if ((c = lookChar()) == '\n') {
+	getChar();
+      }
       return;
     }
   }
