@@ -14,6 +14,7 @@
 #endif
 
 #include "gtypes.h"
+#include "CharTypes.h"
 
 class GString;
 class GfxState;
@@ -45,10 +46,13 @@ public:
   // Does this device use drawChar() or drawString()?
   virtual GBool useDrawChar() = 0;
 
+  // Does this device need non-text content?
+  virtual GBool needNonText() { return gTrue; }
+
   //----- initialization and control
 
   // Set default transform matrix.
-  virtual void setDefaultCTM(double *ctm1);
+  virtual void setDefaultCTM(double *ctm);
 
   // Start a page.
   virtual void startPage(int pageNum, GfxState *state) {}
@@ -111,11 +115,10 @@ public:
   virtual void beginString(GfxState *state, GString *s) {}
   virtual void endString(GfxState *state) {}
   virtual void drawChar(GfxState *state, double x, double y,
-			double dx, double dy, Guchar c) {}
-  virtual void drawChar16(GfxState *state, double x, double y,
-			  double dx, double dy, int c) {}
+			double dx, double dy,
+			double originX, double originY,
+			CharCode code, Unicode *u, int uLen) {}
   virtual void drawString(GfxState *state, GString *s) {}
-  virtual void drawString16(GfxState *state, GString *s) {}
 
   //----- image drawing
   virtual void drawImageMask(GfxState *state, Object *ref, Stream *str,
@@ -123,7 +126,7 @@ public:
 			     GBool inlineImg);
   virtual void drawImage(GfxState *state, Object *ref, Stream *str,
 			 int width, int height, GfxImageColorMap *colorMap,
-			 GBool inlineImg);
+			 int *maskColors, GBool inlineImg);
 
 #if OPI_SUPPORT
   //----- OPI functions
@@ -133,8 +136,8 @@ public:
 
 private:
 
-  double ctm[6];		// coordinate transform matrix
-  double ictm[6];		// inverse CTM
+  double defCTM[6];		// default coordinate transform matrix
+  double defICTM[6];		// inverse of default CTM
 };
 
 #endif
