@@ -16,38 +16,25 @@
 #include <stddef.h>
 #include "config.h"
 #include "Object.h"
+#include "GlobalParams.h"
 #include "OutputDev.h"
 
 class GfxPath;
 class GfxFont;
 class GfxColorSpace;
-
-//------------------------------------------------------------------------
-// Parameters
-//------------------------------------------------------------------------
-
-// Generate Level 1 PostScript?
-extern GBool psOutLevel1;
-
-// Generate Level 1 separable PostScript?
-extern GBool psOutLevel1Sep;
-
-// Generate Encapsulated PostScript?
-extern GBool psOutEPS;
-
-#if OPI_SUPPORT
-// Generate OPI comments?
-extern GBool psOutOPI;
-#endif
-
-// Paper size.
-extern int paperWidth;
-extern int paperHeight;
+class GfxSeparationColorSpace;
+class PSOutCustomColor;
 
 //------------------------------------------------------------------------
 // PSOutputDev
 //------------------------------------------------------------------------
 
+enum PSOutMode {
+  psModePS,
+  psModeEPS,
+  psModeForm
+};
+
 enum PSFileType {
   psFile,			// write to file
   psPipe,			// write to pipe
@@ -58,9 +45,8 @@ class PSOutputDev: public OutputDev {
 public:
 
   // Open a PostScript output file, and write the prolog.
-  PSOutputDev(char *fileName, Catalog *catalog,
-	      int firstPage, int lastPage,
-	      GBool embedType11, GBool doForm1);
+  PSOutputDev(char *fileName, XRef *xrefA, Catalog *catalog,
+	      int firstPage, int lastPage, PSOutMode modeA);
 
   // Destructor -- writes the trailer and closes the file.
   virtual ~PSOutputDev();
@@ -123,7 +109,6 @@ public:
 
   //----- text drawing
   virtual void drawString(GfxState *state, GString *s);
-  virtual void drawString16(GfxState *state, GString *s);
 
   //----- image drawing
   virtual void drawImageMask(GfxState *state, Object *ref, Stream *str,
@@ -131,7 +116,7 @@ public:
 			     GBool inlineImg);
   virtual void drawImage(GfxState *state, Object *ref, Stream *str,
 			 int width, int height, GfxImageColorMap *colorMap,
-			 GBool inlineImg);
+			 int *maskColors, GBool inlineImg);
 
 #if OPI_SUPPORT
   //----- OPI functions
@@ -147,8 +132,11 @@ private:
   void setupEmbeddedType1Font(Ref *id, char *psName);
   void setupEmbeddedType1Font(GString *fileName, char *psName);
   void setupEmbeddedType1CFont(GfxFont *font, Ref *id, char *psName);
+  void setupEmbeddedTrueTypeFont(GfxFont *font, Ref *id, char *psName);
   void setupImages(Dict *resDict);
   void setupImage(Ref id, Stream *str);
+  void addProcessColor(double c, double m, double y, double k);
+  void addCustomColor(GfxSeparationColorSpace *sepCS);
   void doPath(GfxPath *path);
   void doImageL1(GfxImageColorMap *colorMap,
 		 GBool invert, GBool inlineImg,
@@ -160,21 +148,27 @@ private:
 		 GBool invert, GBool inlineImg,
 		 Stream *str, int width, int height, int len);
   void dumpColorSpaceL2(GfxColorSpace *colorSpace);
+#if OPI_SUPPORT
   void opiBegin20(GfxState *state, Dict *dict);
   void opiBegin13(GfxState *state, Dict *dict);
   void opiTransform(GfxState *state, double x0, double y0,
 		    double *x1, double *y1);
   GBool getFileSpec(Object *fileSpec, Object *fileName);
+#endif
   void writePS(const char *fmt, ...);
   void writePSString(GString *s);
 
-  GBool embedType1;		// embed Type 1 fonts?
-  GBool doForm;			// generate a form?
+  PSLevel level;		// PostScript level (1, 2, separation)
+  PSOutMode mode;		// PostScript mode (PS, EPS, form)
+  int paperWidth;		// width of paper, in pts
+  int paperHeight;		// height of paper, in pts
 
   FILE *f;			// PostScript file
   PSFileType fileType;		// file / pipe / stdout
   int seqPage;			// current sequential page number
 
+  XRef *xref;			// the xref table for this PDF file
+
   Ref *fontIDs;			// list of object IDs of all used fonts
   int fontIDLen;		// number of entries in fontIDs array
   int fontIDSize;		// size of fontIDs array
@@ -191,6 +185,10 @@ private:
 
   GString *embFontList;		// resource comments for embedded fonts
 
+  int processColors;		// used process colors
+  PSOutCustomColor		// used custom colors
+    *customColors;
+
 #if OPI_SUPPORT
   int opi13Nest;		// nesting level of OPI 1.3 objects
   int opi20Nest;		// nesting level of OPI 2.0 objects
