@@ -2,7 +2,7 @@
 //
 // config.h
 //
-// Copyright 1996 Derek B. Noonburg
+// Copyright 1996-2002 Derek B. Noonburg
 //
 //========================================================================
 
@@ -10,18 +10,22 @@
 #define CONFIG_H
 
 //------------------------------------------------------------------------
-// general constants
+// version
 //------------------------------------------------------------------------
 
 // xpdf version
-#define xpdfVersion "0.92"
+#define xpdfVersion "1.00"
 
 // supported PDF version
-#define supportedPDFVersionStr "1.3"
-#define supportedPDFVersionNum 1.3
+#define supportedPDFVersionStr "1.4"
+#define supportedPDFVersionNum 1.4
 
 // copyright notice
-#define xpdfCopyright "Copyright 1996-2000 Derek B. Noonburg"
+#define xpdfCopyright "Copyright 1996-2002 Derek B. Noonburg"
+
+//------------------------------------------------------------------------
+// paper size
+//------------------------------------------------------------------------
 
 // default paper size (in points) for PostScript output
 #ifdef A4_PAPER
@@ -32,11 +36,24 @@
 #define defPaperHeight 792
 #endif
 
-// config file name
-#if defined(VMS)
-#define xpdfConfigFile "xpdfrc"
+//------------------------------------------------------------------------
+// config file (xpdfrc) path
+//------------------------------------------------------------------------
+
+// user config file name, relative to the user's home directory
+#if defined(VMS) || (defined(WIN32) && !defined(__CYGWIN32__))
+#define xpdfUserConfigFile "xpdfrc"
 #else
-#define xpdfConfigFile ".xpdfrc"
+#define xpdfUserConfigFile ".xpdfrc"
+#endif
+
+// system config file name (set via the configure script)
+#ifdef SYSTEM_XPDFRC
+#define xpdfSysConfigFile SYSTEM_XPDFRC
+#else
+// under Windows, we get the directory with the executable and then
+// append this file name
+#define xpdfSysConfigFile "xpdfrc"
 #endif
 
 //------------------------------------------------------------------------
@@ -46,14 +63,8 @@
 // default maximum size of color cube to allocate
 #define defaultRGBCube 5
 
-// number of X server fonts to cache
-#define serverFontCacheSize 16
-
-// number of Type 1 (t1lib) fonts to cache
-#define t1FontCacheSize 32
-
-// number of TrueType (FreeType) fonts to cache
-#define ttFontCacheSize 32
+// number of fonts (combined t1lib, FreeType, X server) to cache
+#define xOutFontCacheSize 64
 
 //------------------------------------------------------------------------
 // popen
@@ -64,7 +75,7 @@
 #define pclose _pclose
 #endif
 
-#if defined(VMS) || defined(VMCMS) || defined(DOS) || defined(OS2) || defined(WIN32) || defined(__DJGPP__) || defined(__CYGWIN32) || defined(MACOS)
+#if defined(VMS) || defined(VMCMS) || defined(DOS) || defined(OS2) || defined(__EMX__) || defined(WIN32) || defined(__DJGPP__) || defined(__CYGWIN32__) || defined(MACOS)
 #define POPEN_READ_MODE "rb"
 #else
 #define POPEN_READ_MODE "r"
